==> haskell-type-hint-0.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-HISDBRoTJRK2Mq187mI2H
key:                  type-hint-0.1-HISDBRoTJRK2Mq187mI2H
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  05a8b5ac7122c229d3a43a121f3c7aee
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.0.2/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-hint
hs-libraries:         HStype-hint-0.1-HISDBRoTJRK2Mq187mI2H
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-KKnJgUdWloncAAGzhk3ln
key:                  type-hint-0.1-KKnJgUdWloncAAGzhk3ln
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  3de9d6acb70d6510b1cd6ab63b45b27b
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-hint
hs-libraries:         HStype-hint-0.1-KKnJgUdWloncAAGzhk3ln
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
